import { HTMLAttributes, FC, ReactNode } from 'react';
declare type BaseElement = HTMLDivElement;
declare type BaseProps = HTMLAttributes<BaseElement>;
/**
 * Common padding of content in Dialog/Card
 */
export declare const CONTENT_PADDING: "24px";
export interface TextBlockProps extends BaseProps {
    /**
     * `class` to be passed to the component.
     */
    readonly className?: BaseProps['className'];
    readonly text: string;
    readonly caption?: string;
}
export declare const TextBlock: FC<TextBlockProps>;
/**
 * SpaceBlock
 *
 * A block for adjusting space between elements in Dialog/Card.
 *
 * */
export declare const SpaceBlock: import("styled-components").StyledComponent<"div", import("styled-components").DefaultTheme, {
    readonly variant: 8 | 16 | 24 | 32;
}, never>;
/**
 * ContentDivider
 *
 * It shows an edge to edge divider line in a content
 */
export declare const ContentDivider: import("styled-components").StyledComponent<"div", import("styled-components").DefaultTheme, import("../Divider").NormalDividerProps | import("../Divider").MiddleDividerProps | import("../Divider").InsetDividerProps, never>;
export interface FormSectionProps extends BaseProps {
    readonly children?: ReactNode;
    /**
     * `class` to be passed to the component.
     */
    readonly className?: BaseProps['className'];
    readonly title?: string;
}
export declare const FormSection: FC<FormSectionProps>;
/**
 * List parts in a content
 */
declare type ListHeightType = 'medium' | 'large';
export declare const ContentListItem: import("styled-components").StyledComponent<"div", import("styled-components").DefaultTheme, {
    readonly listHeight?: ListHeightType | undefined;
}, never>;
export interface ContentListItemWithHoverProps extends BaseProps {
    readonly children?: ReactNode;
    /**
     * `class` to be passed to the component.
     */
    readonly className?: BaseProps['className'];
    readonly listHeight?: ListHeightType;
    readonly onHover: (hover: boolean) => void;
}
export declare const ContentListItemWithHover: FC<ContentListItemWithHoverProps>;
export {};
