"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.DraggableListItem = exports.DraggableList = void 0;
var _react = require("react");
var _styledComponents = _interopRequireDefault(require("styled-components"));
var _Divider = require("../Divider");
var _Icon = require("../Icon");
var _designparams = require("../designparams");
var _utils = require("./utils");
var _jsxRuntime = require("react/jsx-runtime");
var _excluded = ["children"],
  _excluded2 = ["children", "onChange"];
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
var DraggableItem = _styledComponents.default.div.withConfig({
  displayName: "DraggableList__DraggableItem",
  componentId: "sc-fdmv69-0"
})(["display:flex;align-items:center;height:", ";"], _designparams.componentSize.large);
var DraggableHandle = _styledComponents.default.div.withConfig({
  displayName: "DraggableList__DraggableHandle",
  componentId: "sc-fdmv69-1"
})(["color:", ";cursor:move;"], _ref => {
  var {
    theme
  } = _ref;
  return theme.color.element01();
});
var DragHandleIcon = () => /*#__PURE__*/(0, _jsxRuntime.jsx)("svg", {
  viewBox: "0 0 24 24",
  width: "1em",
  height: "1em",
  children: /*#__PURE__*/(0, _jsxRuntime.jsx)("path", {
    d: "m20 9h-16v2h16v-2zm-16 6h16v-2h-16v2z"
  })
});
var DraggableListItemStyled = _styledComponents.default.div.withConfig({
  displayName: "DraggableList__DraggableListItemStyled",
  componentId: "sc-fdmv69-2"
})(["display:flex;height:100%;flex-grow:1;align-items:center;justify-content:space-between;width:100%;"]);
var DraggableListItem = _ref2 => {
  var {
      children
    } = _ref2,
    props = _objectWithoutProperties(_ref2, _excluded);
  var onGrabHandle = (0, _react.useCallback)(e => {
    var _e$currentTarget$pare, _e$currentTarget$pare2;
    (_e$currentTarget$pare = e.currentTarget.parentElement) === null || _e$currentTarget$pare === void 0 ? void 0 : (_e$currentTarget$pare2 = _e$currentTarget$pare.parentElement) === null || _e$currentTarget$pare2 === void 0 ? void 0 : _e$currentTarget$pare2.setAttribute('draggable', 'true');
  }, []);
  var onReleaseHandle = (0, _react.useCallback)(e => {
    var _e$currentTarget$pare3, _e$currentTarget$pare4;
    (_e$currentTarget$pare3 = e.currentTarget.parentElement) === null || _e$currentTarget$pare3 === void 0 ? void 0 : (_e$currentTarget$pare4 = _e$currentTarget$pare3.parentElement) === null || _e$currentTarget$pare4 === void 0 ? void 0 : _e$currentTarget$pare4.setAttribute('draggable', 'false');
  }, []);
  return /*#__PURE__*/(0, _jsxRuntime.jsxs)(DraggableListItemStyled, _objectSpread(_objectSpread({}, props), {}, {
    children: [/*#__PURE__*/(0, _jsxRuntime.jsx)("div", {
      children: children
    }), props.disabled === true ? null : /*#__PURE__*/(0, _jsxRuntime.jsx)(DraggableHandle, {
      onMouseDown: onGrabHandle,
      onMouseUp: onReleaseHandle,
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Icon.Icon, {
        icon: DragHandleIcon
      })
    })]
  }));
};

/**
 * Draggable list
 *
 * A list where the items can be dragged through a drag handler
 * rendered on the right side of the list items.
 */
exports.DraggableListItem = DraggableListItem;
var DraggableList = _ref3 => {
  var {
      children,
      onChange
    } = _ref3,
    props = _objectWithoutProperties(_ref3, _excluded2);
  var childElements = (0, _react.useMemo)(() => _react.Children.toArray(children), [children]);
  var locked = (0, _react.useMemo)(() => childElements.map(_utils.isElementDisabled), [childElements]);
  var elementRange = (0, _react.useMemo)(() => (0, _utils.range)(childElements.length), [childElements]);
  var [order, setOrder] = (0, _react.useState)(elementRange);
  (0, _react.useLayoutEffect)(() => setOrder(elementRange), [elementRange, childElements.length]);
  var dragIndexRef = (0, _react.useRef)();
  var dropIndexRef = (0, _react.useRef)();
  var onDragStart = (0, _react.useCallback)(e => {
    // Needed for Firefox
    // You need to set some data in the dataTransfer member
    // of the event when the drag start in Firefox
    e.dataTransfer.setData('text', '');
    dragIndexRef.current = Number(e.currentTarget.dataset.index);
  }, []);
  var onDragOver = (0, _react.useCallback)(e => {
    var dragIndex = dragIndexRef.current;
    if (dragIndex === undefined) {
      return;
    }
    // Only re-order elements if we're dragging over a new
    // item in the list to prevent spurious re-renders.
    var dropIndex = Number(e.currentTarget.dataset.index);
    if (dropIndex !== dropIndexRef.current) {
      var _dropIndexRef$current;
      dropIndexRef.current = dropIndex;
      setOrder((0, _utils.move)(elementRange, locked, dragIndex, (_dropIndexRef$current = dropIndexRef.current) !== null && _dropIndexRef$current !== void 0 ? _dropIndexRef$current : 0));
    }
  }, [elementRange, locked]);
  var onDragEnd = (0, _react.useCallback)(() => {
    dragIndexRef.current = undefined;
    dropIndexRef.current = undefined;
    onChange(order);
  }, [order, onChange]);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)("div", _objectSpread(_objectSpread({}, props), {}, {
    children: order.map((childIndex, index) => {
      var el = childElements[childIndex];
      var isLocked = locked[childIndex];
      return /*#__PURE__*/(0, _jsxRuntime.jsxs)("div", {
        children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(DraggableItem, {
          onDragStart: onDragStart,
          onDragOver: isLocked ? undefined : onDragOver,
          onDragEnd: onDragEnd,
          "data-index": index,
          style: {
            opacity: childIndex === dragIndexRef.current ? 0 : undefined
          },
          children: el
        }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_Divider.Divider, {})]
      }, index);
    })
  }));
};
exports.DraggableList = DraggableList;