import { FC, ReactNode } from 'react';
import { Theme } from './theme';
import { ToastsPlacement } from './Toast/ToastsProvider';
import { SimpleToastsDurations } from './Toast';
export interface ToastsOptions {
    /**
     * Position of toasts on the page.
     */
    readonly placement?: ToastsPlacement;
    /**
     * Determine if toasts should be always on top (above any other modal layers),
     * or not (above the main application layer but below any other modal layers).
     *
     * @default true
     */
    readonly alwaysOnTop?: boolean;
    /**
     * Default toast durations
     */
    readonly defaultDurations?: SimpleToastsDurations;
}
interface PracticalProviderProps extends SimpleToastsDurations {
    readonly children?: ReactNode;
    /**
     * The Practical React Components theme to be used.
     */
    readonly theme?: Theme;
    /**
     * The toasts layout.
     *
     * @default Toasts are centered at the top and always visible.
     */
    readonly toastsOptions?: ToastsOptions;
}
export declare const PracticalProvider: FC<PracticalProviderProps>;
interface LayerContextType {
    readonly el: HTMLElement | null;
    readonly id: string;
}
export declare const LayerContext: import("react").Context<LayerContextType>;
interface LayerProps {
    readonly zIndex?: number;
    readonly children?: ReactNode;
}
export declare const Layer: FC<LayerProps>;
export {};
