import { FC, InputHTMLAttributes, ChangeEventHandler } from 'react';
declare type BaseElement = HTMLInputElement;
declare type BaseProps = InputHTMLAttributes<BaseElement>;
export declare type SwitchChangeHandler = ChangeEventHandler<BaseElement>;
export declare type SwitchValueChangeHandler = (value: boolean) => void;
export interface SwitchProps extends BaseProps {
    /**
     * Specifies the name of an input element.
     */
    readonly name?: BaseProps['name'];
    /**
     * `class` to be passed to the component.
     */
    readonly className?: string;
    /**
     * If `true`, the component is switched ON, `false` if OFF.
     */
    readonly checked: boolean;
    /**
     * Native change handler that can be used by formik etc.
     */
    readonly onChange?: SwitchChangeHandler;
    /**
     * Smooth typed value change handler.
     */
    readonly onValueChange?: SwitchValueChangeHandler;
    /**
     * A label for the switch
     * Default `undefined`
     */
    readonly label?: string;
}
export declare const Switch: FC<SwitchProps>;
export declare const SwitchField: FC<SwitchProps & import("../utils").FieldProps>;
export {};
